@@ -15,8 +15,7 @@ from yarl import URL
 from . import connector as connector_mod
 from . import client_exceptions, client_reqrep, hdrs, http, payload
 from .client_exceptions import *  # noqa
-from .client_exceptions import (ClientError, ClientOSError,
-                                ClientResponseError, ServerTimeoutError,
+from .client_exceptions import (ClientError, ClientOSError, ServerTimeoutError,
                                 WSServerHandshakeError)
 from .client_reqrep import *  # noqa
 from .client_reqrep import ClientRequest, ClientResponse
@@ -24,10 +23,12 @@ from .client_ws import ClientWebSocketResponse
 from .connector import *  # noqa
 from .connector import TCPConnector
 from .cookiejar import CookieJar
-from .helpers import PY_35, CeilTimeout, TimeoutHandle, deprecated_noop
+from .helpers import (PY_35, CeilTimeout, TimeoutHandle, deprecated_noop,
+                      sentinel)
 from .http import WS_KEY, WebSocketReader, WebSocketWriter
 from .streams import FlowControlDataQueue
 
+
 __all__ = (client_exceptions.__all__ +  # noqa
            client_reqrep.__all__ +  # noqa
            connector_mod.__all__ +  # noqa
@@ -44,6 +45,8 @@ class ClientSession:
     _source_traceback = None
     _connector = None
 
+    requote_redirect_url = True
+
     def __init__(self, *, connector=None, loop=None, cookies=None,
                  headers=None, skip_auto_headers=None,
                  auth=None, json_serialize=json.dumps,
@@ -51,7 +54,7 @@ class ClientSession:
                  ws_response_class=ClientWebSocketResponse,
                  version=http.HttpVersion11,
                  cookie_jar=None, connector_owner=True, raise_for_status=False,
-                 read_timeout=None, conn_timeout=None):
+                 read_timeout=sentinel, conn_timeout=None):
 
         implicit_loop = False
         if loop is None:
@@ -95,7 +98,8 @@ class ClientSession:
         self._default_auth = auth
         self._version = version
         self._json_serialize = json_serialize
-        self._read_timeout = read_timeout
+        self._read_timeout = (read_timeout if read_timeout is not sentinel
+                              else DEFAULT_TIMEOUT)
         self._conn_timeout = conn_timeout
         self._raise_for_status = raise_for_status
 
@@ -148,7 +152,7 @@ class ClientSession:
                  read_until_eof=True,
                  proxy=None,
                  proxy_auth=None,
-                 timeout=DEFAULT_TIMEOUT):
+                 timeout=sentinel):
 
         # NOTE: timeout clamps existing connect and read timeouts.  We cannot
         # set the default to None because we need to detect if the user wants
@@ -200,7 +204,8 @@ class ClientSession:
         # timeout is cumulative for all request operations
         # (request, redirects, responses, data consuming)
         tm = TimeoutHandle(
-            self._loop, timeout if timeout is not None else self._read_timeout)
+            self._loop,
+            timeout if timeout is not sentinel else self._read_timeout)
         handle = tm.start()
 
         timer = tm.timer()
@@ -217,7 +222,8 @@ class ClientSession:
                         compress=compress, chunked=chunked,
                         expect100=expect100, loop=self._loop,
                         response_class=self._response_class,
-                        proxy=proxy, proxy_auth=proxy_auth, timer=timer)
+                        proxy=proxy, proxy_auth=proxy_auth, timer=timer,
+                        session=self)
 
                     # connection timeout
                     try:
@@ -239,10 +245,6 @@ class ClientSession:
                             raise
                     except ClientError:
                         raise
-                    except http.HttpProcessingError as exc:
-                        raise ClientResponseError(
-                            code=exc.code,
-                            message=exc.message, headers=exc.headers) from exc
                     except OSError as exc:
                         raise ClientOSError(*exc.args) from exc
 
@@ -277,7 +279,8 @@ class ClientSession:
                                 "a redirect [{0.status}] status "
                                 "but response lacks a Location "
                                 "or URI HTTP header".format(resp))
-                        r_url = URL(r_url)
+                        r_url = URL(
+                            r_url, encoded=not self.requote_redirect_url)
 
                         scheme = r_url.scheme
                         if scheme not in ('http', 'https', ''):
@@ -390,18 +393,24 @@ class ClientSession:
             # check handshake
             if resp.status != 101:
                 raise WSServerHandshakeError(
+                    resp.request_info,
+                    resp.history,
                     message='Invalid response status',
                     code=resp.status,
                     headers=resp.headers)
 
             if resp.headers.get(hdrs.UPGRADE, '').lower() != 'websocket':
                 raise WSServerHandshakeError(
+                    resp.request_info,
+                    resp.history,
                     message='Invalid upgrade header',
                     code=resp.status,
                     headers=resp.headers)
 
             if resp.headers.get(hdrs.CONNECTION, '').lower() != 'upgrade':
                 raise WSServerHandshakeError(
+                    resp.request_info,
+                    resp.history,
                     message='Invalid connection header',
                     code=resp.status,
                     headers=resp.headers)
@@ -412,6 +421,8 @@ class ClientSession:
                 hashlib.sha1(sec_key + WS_KEY).digest()).decode()
             if key != match:
                 raise WSServerHandshakeError(
+                    resp.request_info,
+                    resp.history,
                     message='Invalid challenge response',
                     code=resp.status,
                     headers=resp.headers)
@@ -524,7 +535,7 @@ class ClientSession:
                 self._connector.close()
             self._connector = None
 
-        return deprecated_noop('ClientSession.close() is not coroutine')
+        return deprecated_noop('ClientSession.close() is a coroutine')
 
     @property
     def closed(self):
@@ -654,7 +665,7 @@ class _WSRequestContextManager(_BaseRequestContextManager):
             yield from self._resp.close()
 
 
-class _DetachedRequestContextManager(_RequestContextManager):
+class _SessionRequestContextManager(_RequestContextManager):
 
     __slots__ = _RequestContextManager.__slots__ + ('_session', )
 
@@ -678,9 +689,6 @@ class _DetachedRequestContextManager(_RequestContextManager):
                 self._session.close()
                 raise
 
-    def __del__(self):
-        self._session.detach()
-
 
 def request(method, url, *,
             params=None,
@@ -743,7 +751,7 @@ def request(method, url, *,
         loop=loop, cookies=cookies, version=version,
         connector=connector, connector_owner=connector_owner)
 
-    return _DetachedRequestContextManager(
+    return _SessionRequestContextManager(
         session._request(method, url,
                          params=params,
                          data=data,
