@@ -1,10 +1,12 @@
-"""Basic http server with minimal setup"""
-import aiohttp
-import aiohttp.server
+#!/usr/bin/env python3
+"""Basic HTTP server with minimal setup"""
 
 import asyncio
-from urllib.parse import urlparse, parse_qsl
-from aiohttp.multidict import MultiDict
+from urllib.parse import parse_qsl, urlparse
+
+import aiohttp
+import aiohttp.server
+from aiohttp import MultiDict
 
 
 class HttpRequestHandler(aiohttp.server.ServerHttpProtocol):
@@ -35,7 +37,7 @@ if __name__ == '__main__':
     loop = asyncio.get_event_loop()
     f = loop.create_server(
         lambda: HttpRequestHandler(debug=True, keep_alive=75),
-        '0.0.0.0', '8080')
+        '0.0.0.0', 8080)
     srv = loop.run_until_complete(f)
     print('serving on', srv.sockets[0].getsockname())
     try:
