@@ -1,7 +1,13 @@
+import re
+import sys
+
+import pytest
+
+
 pytest_plugins = 'pytester'
 
 
-def test_myplugin(testdir):
+def test_aiohttp_plugin(testdir):
     testdir.makepyfile("""\
 import asyncio
 import pytest
@@ -150,3 +156,27 @@ def test_client_failed_to_create(test_client):
     # i dont know how to fix this
     # result = testdir.runpytest('-p', 'no:sugar')
     # result.assert_outcomes(passed=11, failed=1)
+
+
+@pytest.mark.skipif(sys.version_info < (3, 5), reason='old python')
+def test_warning_checks(testdir, capsys):
+    testdir.makepyfile("""\
+import asyncio
+
+pytest_plugins = 'aiohttp.pytest_plugin'
+
+async def foobar():
+    return 123
+
+async def test_good():
+    v = await foobar()
+    assert v == 123
+
+async def test_bad():
+    foobar()
+""")
+    result = testdir.runpytest('-p', 'no:sugar', '-s')
+    result.assert_outcomes(passed=1, failed=1)
+    stdout, _ = capsys.readouterr()
+    assert ("test_warning_checks.py:__LINE__:coroutine 'foobar' was "
+            "never awaited" in re.sub('\d{2,}', '__LINE__', stdout))
